@@ -16,6 +16,7 @@ from ._standards.nacebel2008 import NACEBEL2008, NACEBEL2008_to_NACE2
 from ._standards.naf1 import NAF1, NAF1_to_NAF2
 from ._standards.naf2 import NAF2, NAF2_to_NACE2
 from ._standards.naics2017 import NAICS2017, NAICS2017_to_ISIC4
+from ._standards.sbi2008 import SBI2008, SBI2008_to_NACE2
 from ._standards.scian2018 import SCIAN2018, SCIAN2018_to_ISIC4
 from ._standards.skd2002 import SKD2002, SKD2002_to_NACE2, SKD2002_to_SKD2008
 from ._standards.skd2008 import SKD2008, SKD2008_to_SKD2002
@@ -47,5 +48,6 @@ ToISIC4 = ComposedGraph(
         CAEM2005_to_CAEM2009,
         CAEM2009_to_ISIC4,
         CAEM2005_to_ISIC3,
+        SBI2008_to_NACE2,
     ],
 )
